@@ -277,7 +277,7 @@ class MultipartUpload(UploadBase):
 
         checksum_object = sync_helpers._get_checksum_object(self._checksum_type)
 
-        if checksum_object:
+        if checksum_object is not None:
             checksum_object.update(data)
             actual_checksum = sync_helpers.prepare_checksum_digest(
                 checksum_object.digest()
