@@ -12,11 +12,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import http.client
 import io
 
 import mock
 import pytest
-from six.moves import http_client
 
 from google.resumable_media import common
 from google.resumable_media import _helpers
@@ -24,10 +24,8 @@ from google.resumable_media.requests import download as download_mod
 from google.resumable_media.requests import _request_helpers
 
 
-EXAMPLE_URL = (
-    u"https://www.googleapis.com/download/storage/v1/b/"
-    u"{BUCKET}/o/{OBJECT}?alt=media"
-)
+URL_PREFIX = "https://www.googleapis.com/download/storage/v1/b/{BUCKET}/o/"
+EXAMPLE_URL = URL_PREFIX + "{OBJECT}?alt=media"
 EXPECTED_TIMEOUT = (61, 60)
 
 
@@ -60,7 +58,7 @@ class TestDownload(object):
         chunk1 = b"first chunk, count starting at 0. "
         chunk2 = b"second chunk, or chunk 1, which is better? "
         chunk3 = b"ordinals and numerals and stuff."
-        header_value = u"crc32c=qmNCyg==,md5=fPAJHnnoi/+NadyNxT2c2w=="
+        header_value = "crc32c=qmNCyg==,md5=fPAJHnnoi/+NadyNxT2c2w=="
         headers = {_helpers._HASH_HEADER: header_value}
         response = _mock_response(chunks=[chunk1, chunk2, chunk3], headers=headers)
 
@@ -84,8 +82,8 @@ class TestDownload(object):
         chunk1 = b"first chunk, count starting at 0. "
         chunk2 = b"second chunk, or chunk 1, which is better? "
         chunk3 = b"ordinals and numerals and stuff."
-        bad_checksum = u"d3JvbmcgbiBtYWRlIHVwIQ=="
-        header_value = u"crc32c={bad},md5={bad}".format(bad=bad_checksum)
+        bad_checksum = "d3JvbmcgbiBtYWRlIHVwIQ=="
+        header_value = "crc32c={bad},md5={bad}".format(bad=bad_checksum)
         headers = {_helpers._HASH_HEADER: header_value}
         response = _mock_response(chunks=[chunk1, chunk2, chunk3], headers=headers)
 
@@ -97,10 +95,10 @@ class TestDownload(object):
         error = exc_info.value
         assert error.response is response
         assert len(error.args) == 1
-        if checksum == u"md5":
-            good_checksum = u"fPAJHnnoi/+NadyNxT2c2w=="
+        if checksum == "md5":
+            good_checksum = "fPAJHnnoi/+NadyNxT2c2w=="
         else:
-            good_checksum = u"qmNCyg=="
+            good_checksum = "qmNCyg=="
         msg = download_mod._CHECKSUM_MISMATCH.format(
             EXAMPLE_URL, bad_checksum, good_checksum, checksum_type=checksum.upper()
         )
@@ -124,8 +122,8 @@ class TestDownload(object):
         chunk1 = b"first chunk, count starting at 0. "
         chunk2 = b"second chunk, or chunk 1, which is better? "
         chunk3 = b"ordinals and numerals and stuff."
-        bad_checksum = u"d3JvbmcgbiBtYWRlIHVwIQ=="
-        header_value = u"crc32c={bad},md5={bad}".format(bad=bad_checksum)
+        bad_checksum = "d3JvbmcgbiBtYWRlIHVwIQ=="
+        header_value = "crc32c={bad},md5={bad}".format(bad=bad_checksum)
         headers = {_helpers._HASH_HEADER: header_value}
         response = _mock_response(chunks=[chunk1, chunk2, chunk3], headers=headers)
 
@@ -165,18 +163,18 @@ class TestDownload(object):
         assert ret_val is transport.request.return_value
 
         called_kwargs = {
-            u"data": None,
-            u"headers": download._headers,
-            u"timeout": EXPECTED_TIMEOUT if timeout is None else timeout,
+            "data": None,
+            "headers": download._headers,
+            "timeout": EXPECTED_TIMEOUT if timeout is None else timeout,
         }
         if chunks:
             assert stream is not None
-            called_kwargs[u"stream"] = True
+            called_kwargs["stream"] = True
 
-        transport.request.assert_called_once_with(u"GET", EXAMPLE_URL, **called_kwargs)
+        transport.request.assert_called_once_with("GET", EXAMPLE_URL, **called_kwargs)
 
-        range_bytes = u"bytes={:d}-{:d}".format(0, end)
-        assert download._headers[u"range"] == range_bytes
+        range_bytes = "bytes={:d}-{:d}".format(0, end)
+        assert download._headers["range"] == range_bytes
         assert download.finished
 
         return transport
@@ -209,7 +207,7 @@ class TestDownload(object):
     def test_consume_with_stream_hash_check_success(self, checksum):
         stream = io.BytesIO()
         chunks = (b"up down ", b"charlie ", b"brown")
-        header_value = u"crc32c=UNIQxg==,md5=JvS1wjMvfbCXgEGeaJJLDQ=="
+        header_value = "crc32c=UNIQxg==,md5=JvS1wjMvfbCXgEGeaJJLDQ=="
         headers = {_helpers._HASH_HEADER: header_value}
         transport = self._consume_helper(
             stream=stream, chunks=chunks, response_headers=headers, checksum=checksum
@@ -231,8 +229,8 @@ class TestDownload(object):
         download = download_mod.Download(EXAMPLE_URL, stream=stream, checksum=checksum)
 
         chunks = (b"zero zero", b"niner tango")
-        bad_checksum = u"anVzdCBub3QgdGhpcyAxLA=="
-        header_value = u"crc32c={bad},md5={bad}".format(bad=bad_checksum)
+        bad_checksum = "anVzdCBub3QgdGhpcyAxLA=="
+        header_value = "crc32c={bad},md5={bad}".format(bad=bad_checksum)
         headers = {_helpers._HASH_HEADER: header_value}
         transport = mock.Mock(spec=["request"])
         transport.request.return_value = _mock_response(chunks=chunks, headers=headers)
@@ -248,10 +246,10 @@ class TestDownload(object):
         error = exc_info.value
         assert error.response is transport.request.return_value
         assert len(error.args) == 1
-        if checksum == u"md5":
-            good_checksum = u"1A/dxEpys717C6FH7FIWDw=="
+        if checksum == "md5":
+            good_checksum = "1A/dxEpys717C6FH7FIWDw=="
         else:
-            good_checksum = u"GvNZlg=="
+            good_checksum = "GvNZlg=="
         msg = download_mod._CHECKSUM_MISMATCH.format(
             EXAMPLE_URL, bad_checksum, good_checksum, checksum_type=checksum.upper()
         )
@@ -259,7 +257,7 @@ class TestDownload(object):
 
         # Check mocks.
         transport.request.assert_called_once_with(
-            u"GET",
+            "GET",
             EXAMPLE_URL,
             data=None,
             headers={},
@@ -271,29 +269,9 @@ class TestDownload(object):
         headers = {}  # Empty headers
         end = 16383
         self._consume_helper(end=end, headers=headers)
-        range_bytes = u"bytes={:d}-{:d}".format(0, end)
+        range_bytes = "bytes={:d}-{:d}".format(0, end)
         # Make sure the headers have been modified.
-        assert headers == {u"range": range_bytes}
-
-    def test_consume_with_retries(self):
-        download = download_mod.Download(EXAMPLE_URL)
-        transport = mock.Mock(spec=["request"])
-        response = _mock_response()
-        transport.request.return_value = response
-        ret_val = download._consume_with_retries(
-            func=download._consume,
-            transport=transport,
-            timeout=EXPECTED_TIMEOUT,
-        )
-
-        assert ret_val is response
-        transport.request.assert_called_once_with(
-            u"GET",
-            EXAMPLE_URL,
-            data=None,
-            headers={},
-            timeout=EXPECTED_TIMEOUT,
-        )
+        assert headers == {"range": range_bytes}
 
 
 class TestRawDownload(object):
@@ -327,7 +305,7 @@ class TestRawDownload(object):
         chunk1 = b"first chunk, count starting at 0. "
         chunk2 = b"second chunk, or chunk 1, which is better? "
         chunk3 = b"ordinals and numerals and stuff."
-        header_value = u"crc32c=qmNCyg==,md5=fPAJHnnoi/+NadyNxT2c2w=="
+        header_value = "crc32c=qmNCyg==,md5=fPAJHnnoi/+NadyNxT2c2w=="
         headers = {_helpers._HASH_HEADER: header_value}
         response = _mock_raw_response(chunks=[chunk1, chunk2, chunk3], headers=headers)
 
@@ -353,8 +331,8 @@ class TestRawDownload(object):
         chunk1 = b"first chunk, count starting at 0. "
         chunk2 = b"second chunk, or chunk 1, which is better? "
         chunk3 = b"ordinals and numerals and stuff."
-        bad_checksum = u"d3JvbmcgbiBtYWRlIHVwIQ=="
-        header_value = u"crc32c={bad},md5={bad}".format(bad=bad_checksum)
+        bad_checksum = "d3JvbmcgbiBtYWRlIHVwIQ=="
+        header_value = "crc32c={bad},md5={bad}".format(bad=bad_checksum)
         headers = {_helpers._HASH_HEADER: header_value}
         response = _mock_raw_response(chunks=[chunk1, chunk2, chunk3], headers=headers)
 
@@ -366,10 +344,10 @@ class TestRawDownload(object):
         error = exc_info.value
         assert error.response is response
         assert len(error.args) == 1
-        if checksum == u"md5":
-            good_checksum = u"fPAJHnnoi/+NadyNxT2c2w=="
+        if checksum == "md5":
+            good_checksum = "fPAJHnnoi/+NadyNxT2c2w=="
         else:
-            good_checksum = u"qmNCyg=="
+            good_checksum = "qmNCyg=="
         msg = download_mod._CHECKSUM_MISMATCH.format(
             EXAMPLE_URL, bad_checksum, good_checksum, checksum_type=checksum.upper()
         )
@@ -393,8 +371,8 @@ class TestRawDownload(object):
         chunk1 = b"first chunk, count starting at 0. "
         chunk2 = b"second chunk, or chunk 1, which is better? "
         chunk3 = b"ordinals and numerals and stuff."
-        bad_checksum = u"d3JvbmcgbiBtYWRlIHVwIQ=="
-        header_value = u"crc32c={bad},md5={bad}".format(bad=bad_checksum)
+        bad_checksum = "d3JvbmcgbiBtYWRlIHVwIQ=="
+        header_value = "crc32c={bad},md5={bad}".format(bad=bad_checksum)
         headers = {_helpers._HASH_HEADER: header_value}
         response = _mock_response(chunks=[chunk1, chunk2, chunk3], headers=headers)
 
@@ -436,7 +414,7 @@ class TestRawDownload(object):
         if chunks:
             assert stream is not None
         transport.request.assert_called_once_with(
-            u"GET",
+            "GET",
             EXAMPLE_URL,
             data=None,
             headers=download._headers,
@@ -444,8 +422,8 @@ class TestRawDownload(object):
             timeout=EXPECTED_TIMEOUT if timeout is None else timeout,
         )
 
-        range_bytes = u"bytes={:d}-{:d}".format(0, end)
-        assert download._headers[u"range"] == range_bytes
+        range_bytes = "bytes={:d}-{:d}".format(0, end)
+        assert download._headers["range"] == range_bytes
         assert download.finished
 
         return transport
@@ -478,7 +456,7 @@ class TestRawDownload(object):
     def test_consume_with_stream_hash_check_success(self, checksum):
         stream = io.BytesIO()
         chunks = (b"up down ", b"charlie ", b"brown")
-        header_value = u"crc32c=UNIQxg==,md5=JvS1wjMvfbCXgEGeaJJLDQ=="
+        header_value = "crc32c=UNIQxg==,md5=JvS1wjMvfbCXgEGeaJJLDQ=="
         headers = {_helpers._HASH_HEADER: header_value}
         transport = self._consume_helper(
             stream=stream, chunks=chunks, response_headers=headers, checksum=checksum
@@ -502,8 +480,8 @@ class TestRawDownload(object):
         )
 
         chunks = (b"zero zero", b"niner tango")
-        bad_checksum = u"anVzdCBub3QgdGhpcyAxLA=="
-        header_value = u"crc32c={bad},md5={bad}".format(bad=bad_checksum)
+        bad_checksum = "anVzdCBub3QgdGhpcyAxLA=="
+        header_value = "crc32c={bad},md5={bad}".format(bad=bad_checksum)
         headers = {_helpers._HASH_HEADER: header_value}
         transport = mock.Mock(spec=["request"])
         transport.request.return_value = _mock_raw_response(
@@ -521,10 +499,10 @@ class TestRawDownload(object):
         error = exc_info.value
         assert error.response is transport.request.return_value
         assert len(error.args) == 1
-        if checksum == u"md5":
-            good_checksum = u"1A/dxEpys717C6FH7FIWDw=="
+        if checksum == "md5":
+            good_checksum = "1A/dxEpys717C6FH7FIWDw=="
         else:
-            good_checksum = u"GvNZlg=="
+            good_checksum = "GvNZlg=="
         msg = download_mod._CHECKSUM_MISMATCH.format(
             EXAMPLE_URL, bad_checksum, good_checksum, checksum_type=checksum.upper()
         )
@@ -532,7 +510,7 @@ class TestRawDownload(object):
 
         # Check mocks.
         transport.request.assert_called_once_with(
-            u"GET",
+            "GET",
             EXAMPLE_URL,
             data=None,
             headers={},
@@ -544,43 +522,22 @@ class TestRawDownload(object):
         headers = {}  # Empty headers
         end = 16383
         self._consume_helper(end=end, headers=headers)
-        range_bytes = u"bytes={:d}-{:d}".format(0, end)
+        range_bytes = "bytes={:d}-{:d}".format(0, end)
         # Make sure the headers have been modified.
-        assert headers == {u"range": range_bytes}
-
-    def test_consume_with_retries(self):
-        download = download_mod.RawDownload(EXAMPLE_URL)
-        transport = mock.Mock(spec=["request"])
-        response = _mock_response()
-        transport.request.return_value = response
-        ret_val = download._consume_with_retries(
-            func=download._consume,
-            transport=transport,
-            timeout=EXPECTED_TIMEOUT,
-        )
-
-        assert ret_val is response
-        transport.request.assert_called_once_with(
-            u"GET",
-            EXAMPLE_URL,
-            data=None,
-            headers={},
-            stream=True,
-            timeout=EXPECTED_TIMEOUT,
-        )
+        assert headers == {"range": range_bytes}
 
 
 class TestChunkedDownload(object):
     @staticmethod
     def _response_content_range(start_byte, end_byte, total_bytes):
-        return u"bytes {:d}-{:d}/{:d}".format(start_byte, end_byte, total_bytes)
+        return "bytes {:d}-{:d}/{:d}".format(start_byte, end_byte, total_bytes)
 
     def _response_headers(self, start_byte, end_byte, total_bytes):
         content_length = end_byte - start_byte + 1
         resp_range = self._response_content_range(start_byte, end_byte, total_bytes)
         return {
-            u"content-length": u"{:d}".format(content_length),
-            u"content-range": resp_range,
+            "content-length": "{:d}".format(content_length),
+            "content-range": resp_range,
         }
 
     def _mock_response(
@@ -608,7 +565,7 @@ class TestChunkedDownload(object):
             start + chunk_size - 1,
             total_bytes,
             content=content,
-            status_code=int(http_client.OK),
+            status_code=int(http.client.OK),
         )
 
         return transport
@@ -631,10 +588,10 @@ class TestChunkedDownload(object):
         # Actually consume the chunk and check the output.
         ret_val = download.consume_next_chunk(transport)
         assert ret_val is transport.request.return_value
-        range_bytes = u"bytes={:d}-{:d}".format(start, start + chunk_size - 1)
-        download_headers = {u"range": range_bytes}
+        range_bytes = "bytes={:d}-{:d}".format(start, start + chunk_size - 1)
+        download_headers = {"range": range_bytes}
         transport.request.assert_called_once_with(
-            u"GET",
+            "GET",
             EXAMPLE_URL,
             data=None,
             headers=download_headers,
@@ -660,55 +617,28 @@ class TestChunkedDownload(object):
         # Actually consume the chunk and check the output.
         download.consume_next_chunk(transport, timeout=14.7)
 
-        range_bytes = u"bytes={:d}-{:d}".format(start, start + chunk_size - 1)
-        download_headers = {u"range": range_bytes}
+        range_bytes = "bytes={:d}-{:d}".format(start, start + chunk_size - 1)
+        download_headers = {"range": range_bytes}
         transport.request.assert_called_once_with(
-            u"GET",
+            "GET",
             EXAMPLE_URL,
             data=None,
             headers=download_headers,
             timeout=14.7,
         )
 
-    def test_consume_with_retries(self):
-        start = 1536
-        stream = io.BytesIO()
-        data = b"Just one chunk."
-        chunk_size = len(data)
-        download = download_mod.ChunkedDownload(
-            EXAMPLE_URL, chunk_size, stream, start=start
-        )
-        total_bytes = 16384
-        transport = self._mock_transport(start, chunk_size, total_bytes, content=data)
-
-        download._consume_with_retries(
-            func=download._consume_next_chunk,
-            transport=transport,
-            timeout=EXPECTED_TIMEOUT,
-        )
-
-        range_bytes = u"bytes={:d}-{:d}".format(start, start + chunk_size - 1)
-        download_headers = {u"range": range_bytes}
-        transport.request.assert_called_once_with(
-            u"GET",
-            EXAMPLE_URL,
-            data=None,
-            headers=download_headers,
-            timeout=EXPECTED_TIMEOUT,
-        )
-
 
 class TestRawChunkedDownload(object):
     @staticmethod
     def _response_content_range(start_byte, end_byte, total_bytes):
-        return u"bytes {:d}-{:d}/{:d}".format(start_byte, end_byte, total_bytes)
+        return "bytes {:d}-{:d}/{:d}".format(start_byte, end_byte, total_bytes)
 
     def _response_headers(self, start_byte, end_byte, total_bytes):
         content_length = end_byte - start_byte + 1
         resp_range = self._response_content_range(start_byte, end_byte, total_bytes)
         return {
-            u"content-length": u"{:d}".format(content_length),
-            u"content-range": resp_range,
+            "content-length": "{:d}".format(content_length),
+            "content-range": resp_range,
         }
 
     def _mock_response(
@@ -736,7 +666,7 @@ class TestRawChunkedDownload(object):
             start + chunk_size - 1,
             total_bytes,
             content=content,
-            status_code=int(http_client.OK),
+            status_code=int(http.client.OK),
         )
 
         return transport
@@ -759,10 +689,10 @@ class TestRawChunkedDownload(object):
         # Actually consume the chunk and check the output.
         ret_val = download.consume_next_chunk(transport)
         assert ret_val is transport.request.return_value
-        range_bytes = u"bytes={:d}-{:d}".format(start, start + chunk_size - 1)
-        download_headers = {u"range": range_bytes}
+        range_bytes = "bytes={:d}-{:d}".format(start, start + chunk_size - 1)
+        download_headers = {"range": range_bytes}
         transport.request.assert_called_once_with(
-            u"GET",
+            "GET",
             EXAMPLE_URL,
             data=None,
             headers=download_headers,
@@ -789,10 +719,10 @@ class TestRawChunkedDownload(object):
         # Actually consume the chunk and check the output.
         download.consume_next_chunk(transport, timeout=14.7)
 
-        range_bytes = u"bytes={:d}-{:d}".format(start, start + chunk_size - 1)
-        download_headers = {u"range": range_bytes}
+        range_bytes = "bytes={:d}-{:d}".format(start, start + chunk_size - 1)
+        download_headers = {"range": range_bytes}
         transport.request.assert_called_once_with(
-            u"GET",
+            "GET",
             EXAMPLE_URL,
             data=None,
             headers=download_headers,
@@ -805,34 +735,6 @@ class TestRawChunkedDownload(object):
         assert download.bytes_downloaded == chunk_size
         assert download.total_bytes == total_bytes
 
-    def test_consume_with_retries(self):
-        start = 1536
-        stream = io.BytesIO()
-        data = b"Just one chunk."
-        chunk_size = len(data)
-        download = download_mod.RawChunkedDownload(
-            EXAMPLE_URL, chunk_size, stream, start=start
-        )
-        total_bytes = 16384
-        transport = self._mock_transport(start, chunk_size, total_bytes, content=data)
-
-        download._consume_with_retries(
-            func=download._consume_next_chunk,
-            transport=transport,
-            timeout=EXPECTED_TIMEOUT,
-        )
-
-        range_bytes = u"bytes={:d}-{:d}".format(start, start + chunk_size - 1)
-        download_headers = {u"range": range_bytes}
-        transport.request.assert_called_once_with(
-            u"GET",
-            EXAMPLE_URL,
-            data=None,
-            headers=download_headers,
-            stream=True,
-            timeout=EXPECTED_TIMEOUT,
-        )
-
 
 class Test__add_decoder(object):
     def test_non_gzipped(self):
@@ -842,7 +744,7 @@ class Test__add_decoder(object):
         assert md5_hash is mock.sentinel.md5_hash
 
     def test_gzipped(self):
-        headers = {u"content-encoding": u"gzip"}
+        headers = {"content-encoding": "gzip"}
         response_raw = mock.Mock(headers=headers, spec=["headers", "_decoder"])
         md5_hash = download_mod._add_decoder(response_raw, mock.sentinel.md5_hash)
 
@@ -868,7 +770,7 @@ class Test_GzipDecoder(object):
         md5_hash.update.assert_called_once_with(data)
 
 
-def _mock_response(status_code=http_client.OK, chunks=(), headers=None):
+def _mock_response(status_code=http.client.OK, chunks=(), headers=None):
     if headers is None:
         headers = {}
 
@@ -879,12 +781,12 @@ def _mock_response(status_code=http_client.OK, chunks=(), headers=None):
             status_code=int(status_code),
             raw=mock_raw,
             spec=[
-                u"__enter__",
-                u"__exit__",
-                u"iter_content",
-                u"status_code",
-                u"headers",
-                u"raw",
+                "__enter__",
+                "__exit__",
+                "iter_content",
+                "status_code",
+                "headers",
+                "raw",
             ],
         )
         # i.e. context manager returns ``self``.
@@ -900,7 +802,7 @@ def _mock_response(status_code=http_client.OK, chunks=(), headers=None):
         )
 
 
-def _mock_raw_response(status_code=http_client.OK, chunks=(), headers=None):
+def _mock_raw_response(status_code=http.client.OK, chunks=(), headers=None):
     if headers is None:
         headers = {}
 
@@ -911,12 +813,12 @@ def _mock_raw_response(status_code=http_client.OK, chunks=(), headers=None):
         status_code=int(status_code),
         raw=mock_raw,
         spec=[
-            u"__enter__",
-            u"__exit__",
-            u"iter_content",
-            u"status_code",
-            u"headers",
-            u"raw",
+            "__enter__",
+            "__exit__",
+            "iter_content",
+            "status_code",
+            "headers",
+            "raw",
         ],
     )
     # i.e. context manager returns ``self``.
