@@ -125,6 +125,28 @@ class Test_require_status_code(object):
         assert error.args[3:] == status_codes
         callback.assert_called_once_with()
 
+    def test_retryable_failure_without_callback(self):
+        status_codes = (http.client.OK,)
+        retryable_responses = [
+            _make_response(status_code) for status_code in common.RETRYABLE
+        ]
+        callback = mock.Mock(spec=[])
+        for retryable_response in retryable_responses:
+            with pytest.raises(common.InvalidResponse) as exc_info:
+                _helpers.require_status_code(
+                    retryable_response,
+                    status_codes,
+                    self._get_status_code,
+                    callback=callback,
+                )
+
+            error = exc_info.value
+            assert error.response is retryable_response
+            assert len(error.args) == 4
+            assert error.args[1] == retryable_response.status_code
+            assert error.args[3:] == status_codes
+            callback.assert_not_called()
+
 
 class Test_calculate_retry_wait(object):
     @mock.patch("random.randint", return_value=125)
@@ -337,7 +359,7 @@ class Test_wait_and_retry(object):
     @mock.patch("time.sleep")
     @mock.patch("random.randint")
     def test_retry_exceeds_max_cumulative(self, randint_mock, sleep_mock):
-        randint_mock.side_effect = [875, 0, 375, 500, 500, 250, 125, 0]
+        randint_mock.side_effect = [875, 0, 375, 500, 500, 250, 125]
 
         status_codes = (
             http.client.SERVICE_UNAVAILABLE,
@@ -346,7 +368,6 @@ class Test_wait_and_retry(object):
             http.client.INTERNAL_SERVER_ERROR,
             http.client.SERVICE_UNAVAILABLE,
             http.client.BAD_GATEWAY,
-            http.client.GATEWAY_TIMEOUT,
             common.TOO_MANY_REQUESTS,
         )
         responses = [_make_response(status_code) for status_code in status_codes]
@@ -365,47 +386,119 @@ class Test_wait_and_retry(object):
         assert ret_val.status_code == status_codes[-1]
         assert status_codes[-1] in common.RETRYABLE
 
-        assert func.call_count == 8
-        assert func.mock_calls == [mock.call()] * 8
+        assert func.call_count == 7
+        assert func.mock_calls == [mock.call()] * 7
 
         assert randint_mock.call_count == 7
         assert randint_mock.mock_calls == [mock.call(0, 1000)] * 7
 
-        assert sleep_mock.call_count == 7
+        assert sleep_mock.call_count == 6
         sleep_mock.assert_any_call(1.875)
         sleep_mock.assert_any_call(2.0)
         sleep_mock.assert_any_call(4.375)
         sleep_mock.assert_any_call(8.5)
         sleep_mock.assert_any_call(16.5)
         sleep_mock.assert_any_call(32.25)
-        sleep_mock.assert_any_call(64.125)
+
+    @mock.patch("time.sleep")
+    @mock.patch("random.randint")
+    def test_retry_exceeds_max_retries(self, randint_mock, sleep_mock):
+        randint_mock.side_effect = [875, 0, 375, 500, 500, 250, 125]
+
+        status_codes = (
+            http.client.SERVICE_UNAVAILABLE,
+            http.client.GATEWAY_TIMEOUT,
+            common.TOO_MANY_REQUESTS,
+            http.client.INTERNAL_SERVER_ERROR,
+            http.client.SERVICE_UNAVAILABLE,
+            http.client.BAD_GATEWAY,
+            common.TOO_MANY_REQUESTS,
+        )
+        responses = [_make_response(status_code) for status_code in status_codes]
+
+        def raise_response():
+            raise common.InvalidResponse(responses.pop(0))
+
+        func = mock.Mock(side_effect=raise_response)
+
+        retry_strategy = common.RetryStrategy(max_retries=6)
+        try:
+            _helpers.wait_and_retry(func, _get_status_code, retry_strategy)
+        except common.InvalidResponse as e:
+            ret_val = e.response
+
+        assert ret_val.status_code == status_codes[-1]
+        assert status_codes[-1] in common.RETRYABLE
+
+        assert func.call_count == 7
+        assert func.mock_calls == [mock.call()] * 7
+
+        assert randint_mock.call_count == 7
+        assert randint_mock.mock_calls == [mock.call(0, 1000)] * 7
+
+        assert sleep_mock.call_count == 6
+        sleep_mock.assert_any_call(1.875)
+        sleep_mock.assert_any_call(2.0)
+        sleep_mock.assert_any_call(4.375)
+        sleep_mock.assert_any_call(8.5)
+        sleep_mock.assert_any_call(16.5)
+        sleep_mock.assert_any_call(32.25)
+
+    @mock.patch("time.sleep")
+    @mock.patch("random.randint")
+    def test_retry_zero_max_retries(self, randint_mock, sleep_mock):
+        randint_mock.side_effect = [875, 0, 375]
+
+        status_codes = (
+            http.client.SERVICE_UNAVAILABLE,
+            http.client.GATEWAY_TIMEOUT,
+            common.TOO_MANY_REQUESTS,
+        )
+        responses = [_make_response(status_code) for status_code in status_codes]
+
+        def raise_response():
+            raise common.InvalidResponse(responses.pop(0))
+
+        func = mock.Mock(side_effect=raise_response)
+
+        retry_strategy = common.RetryStrategy(max_retries=0)
+        try:
+            _helpers.wait_and_retry(func, _get_status_code, retry_strategy)
+        except common.InvalidResponse as e:
+            ret_val = e.response
+
+        assert func.call_count == 1
+        assert func.mock_calls == [mock.call()] * 1
+        assert ret_val.status_code == status_codes[0]
+
+        assert randint_mock.call_count == 1
+        assert sleep_mock.call_count == 0
 
     @mock.patch("time.sleep")
     @mock.patch("random.randint")
     def test_retry_exceeded_reraises_connection_error(self, randint_mock, sleep_mock):
         randint_mock.side_effect = [875, 0, 375, 500, 500, 250, 125]
 
-        responses = [requests.exceptions.ConnectionError] * 8
+        responses = [requests.exceptions.ConnectionError] * 7
         func = mock.Mock(side_effect=responses, spec=[])
 
         retry_strategy = common.RetryStrategy(max_cumulative_retry=100.0)
         with pytest.raises(requests.exceptions.ConnectionError):
             _helpers.wait_and_retry(func, _get_status_code, retry_strategy)
 
-        assert func.call_count == 8
-        assert func.mock_calls == [mock.call()] * 8
+        assert func.call_count == 7
+        assert func.mock_calls == [mock.call()] * 7
 
         assert randint_mock.call_count == 7
         assert randint_mock.mock_calls == [mock.call(0, 1000)] * 7
 
-        assert sleep_mock.call_count == 7
+        assert sleep_mock.call_count == 6
         sleep_mock.assert_any_call(1.875)
         sleep_mock.assert_any_call(2.0)
         sleep_mock.assert_any_call(4.375)
         sleep_mock.assert_any_call(8.5)
         sleep_mock.assert_any_call(16.5)
         sleep_mock.assert_any_call(32.25)
-        sleep_mock.assert_any_call(64.125)
 
 
 def _make_response(status_code):
